@@ -1,11 +1,10 @@
 import warnings
-
 import numpy as np
 
 from . import ccllib as lib
-
-from .errors import CCLWarning
-from .pyutils import check, _get_spline2d_arrays
+from .errors import CCLWarning, CCLError
+from .pyutils import (check, get_pk_spline_a, get_pk_spline_lk,
+                      _get_spline1d_arrays, _get_spline2d_arrays)
 
 
 class Pk2D(object):
@@ -56,10 +55,8 @@ class Pk2D(object):
              logarithm of the power spectrum. Otherwise, the true value
              of the power spectrum is expected. Note that arrays will be
              interpolated in log space if `is_logp` is set to `True`.
-        cosmo (:class:`~pyccl.core.Cosmology`): Cosmology object. The cosmology
-             object is needed in order if `pkfunc` is not `None`. The object is
-             used to determine the sampling rate in scale factor and
-             wavenumber.
+        cosmo (:class:`~pyccl.core.Cosmology`, optional): Cosmology object.
+             Used to determine sampling rates in scale factor and wavenumber.
         empty (bool): if True, just create an empty object, to be filled
             out later
     """
@@ -70,7 +67,6 @@ class Pk2D(object):
             self.has_psp = False
             return
 
-        status = 0
         if pkfunc is None:  # Initialize power spectrum from 2D array
             # Make sure input makes sense
             if (a_arr is None) or (lk_arr is None) or (pk_arr is None):
@@ -78,7 +74,7 @@ class Pk2D(object):
                                  "you must provide arrays")
 
             # Check that `a` is a monotonically increasing array.
-            if not np.array_equal(a_arr, np.sort(a_arr)):
+            if not np.all((a_arr[1:] - a_arr[:-1]) > 0):
                 raise ValueError("Input scale factor array in `a_arr` is not "
                                  "monotonically increasing.")
 
@@ -93,27 +89,18 @@ class Pk2D(object):
             except Exception:
                 raise ValueError("Can't use input function")
 
-            if cosmo is None:
-                raise ValueError("A cosmology is needed if initializing "
-                                 "power spectrum from a function")
-
             # Set k and a sampling from CCL parameters
-            nk = lib.get_pk_spline_nk(cosmo.cosmo)
-            na = lib.get_pk_spline_na(cosmo.cosmo)
-            a_arr, status = lib.get_pk_spline_a(cosmo.cosmo, na, status)
-            check(status, cosmo=cosmo)
-            lk_arr, status = lib.get_pk_spline_lk(cosmo.cosmo, nk, status)
-            check(status, cosmo=cosmo)
+            a_arr = get_pk_spline_a(cosmo=cosmo)
+            lk_arr = get_pk_spline_lk(cosmo=cosmo)
 
             # Compute power spectrum on 2D grid
-            pkflat = np.zeros([na, nk])
-            for ia, a in enumerate(a_arr):
-                pkflat[ia, :] = pkfunc(k=np.exp(lk_arr), a=a)
+            pkflat = np.array([pkfunc(k=np.exp(lk_arr), a=a) for a in a_arr])
             pkflat = pkflat.flatten()
 
         self.extrap_order_lok = extrap_order_lok
         self.extrap_order_hik = extrap_order_hik
 
+        status = 0
         self.psp, status = lib.set_pk2d_new_from_arrays(lk_arr, a_arr, pkflat,
                                                         int(extrap_order_lok),
                                                         int(extrap_order_hik),
@@ -170,6 +157,21 @@ class Pk2D(object):
             pk_linear (:class:`Pk2D`): a :class:`Pk2D` object containing
                 the linear power spectrum to transform.
         """
+        if cosmo["wa"] != 0:
+            # HALOFIT translates (w0, wa) to a w0_eff. This requires computing
+            # the comoving distance to the CMB, which requires the background
+            # splines being sampled to sufficiently high redshifts.
+            cosmo.compute_distances()
+            _, a = _get_spline1d_arrays(cosmo.cosmo.data.achi)
+            if min(a) > 1/(1 + 3000):
+                raise CCLError("Comoving distance spline does not cover "
+                               "sufficiently high redshifts for HALOFIT. "
+                               "HALOFIT translates (w0, wa) to a w0_eff. This "
+                               "requires computing the comoving distance to "
+                               "the CMB, which requires the background "
+                               "splines being sampled to sufficiently high "
+                               "redshifts. If using the calculator mode, "
+                               "check the support of the background data.")
         pk2d = Pk2D(empty=True)
         status = 0
         ret = lib.apply_halofit(cosmo.cosmo, pk_linear.psp, status)
