@@ -28,6 +28,31 @@ input_growth = ccl.background.growth_factor_unnorm(COSMO, input_a_array)
 input_fgrowth = ccl.background.growth_rate(COSMO, input_a_array)
 
 
+def test_angular_distance_arrs():
+    a_lens = 1.0
+    a_source = 0.5
+
+    # Pass no lens, one source
+    d0 = ccl.angular_diameter_distance(COSMO, a_source)
+
+    # Pass no lens, many sources
+    d = ccl.angular_diameter_distance(COSMO, np.full(10, a_source))
+    assert np.all(np.fabs(d-d0) < 1E-10)
+
+    # One source, one lens
+    d = ccl.angular_diameter_distance(COSMO, a_lens, a_source)
+    assert np.fabs(d0-d) < 1E-10
+
+    # Many sources, one lens
+    d = ccl.angular_diameter_distance(COSMO, a_lens, np.full(10, a_source))
+    assert np.all(np.fabs(d-d0) < 1E-10)
+
+    # Many sources, many lenses
+    d = ccl.angular_diameter_distance(COSMO, np.full(10, a_lens),
+                                      np.full(10, a_source))
+    assert np.all(np.fabs(d-d0) < 1E-10)
+
+
 @pytest.mark.parametrize('a', AVALS)
 @pytest.mark.parametrize('func', [
     ccl.growth_factor,
@@ -52,7 +77,7 @@ def test_background_a_interface(a, func):
             val = func(COSMO, a, a)
             assert np.all(np.isfinite(val))
             assert np.shape(val) == np.shape(a)
-            if(isinstance(a, float) or isinstance(a, int)):
+            if isinstance(a, (int, float)):
                 val1 = ccl.angular_diameter_distance(COSMO, 1., a)
                 val2 = ccl.comoving_angular_distance(COSMO, a)*a
             else:
