@@ -67,7 +67,7 @@ const ccl_configuration default_config = {
  */
 #define GSL_EPSREL_DNDZ 1E-6
 
-const ccl_gsl_params default_gsl_params = {
+ccl_gsl_params ccl_user_gsl_params = {
   GSL_N_ITERATION,                     // N_ITERATION
   GSL_INTEGRATION_GAUSS_KRONROD_POINTS,// INTEGRATION_GAUSS_KRONROD_POINTS
   GSL_EPSREL,                          // INTEGRATION_EPSREL
@@ -100,7 +100,7 @@ const ccl_gsl_params default_gsl_params = {
 #undef GSL_EPSREL_DNDZ
 
 
-const ccl_spline_params default_spline_params = {
+ccl_spline_params ccl_user_spline_params = {
 
   // scale factor spline params
   250,  // A_SPLINE_NA
@@ -259,8 +259,8 @@ ccl_cosmology * ccl_cosmology_create(ccl_parameters params, ccl_configuration co
   ccl_cosmology * cosmo = malloc(sizeof(ccl_cosmology));
   cosmo->params = params;
   cosmo->config = config;
-  cosmo->gsl_params = default_gsl_params;
-  cosmo->spline_params = default_spline_params;
+  cosmo->gsl_params = ccl_user_gsl_params;
+  cosmo->spline_params = ccl_user_spline_params;
   cosmo->spline_params.A_SPLINE_TYPE = gsl_interp_akima;
   cosmo->spline_params.K_SPLINE_TYPE = gsl_interp_akima;
   cosmo->spline_params.M_SPLINE_TYPE = gsl_interp_akima;
@@ -577,6 +577,24 @@ void ccl_get_pk_spline_a_array(ccl_cosmology *cosmo,int ndout,double* doutput,in
   free(d);
 }
 
+void ccl_get_pk_spline_a_array_from_params(ccl_spline_params *spline_params,
+                                           int ndout, double *doutput, int *status) {
+  double *d = NULL;
+  if (*status == 0) {
+    d = ccl_linlog_spacing(spline_params->A_SPLINE_MINLOG_PK,
+      spline_params->A_SPLINE_MIN_PK,
+      spline_params->A_SPLINE_MAX,
+      spline_params->A_SPLINE_NLOG_PK,
+      spline_params->A_SPLINE_NA_PK);
+    if (d == NULL)
+      *status = CCL_ERROR_MEMORY;
+  }
+  if(*status==0)
+    memcpy(doutput, d, ndout*sizeof(double));
+
+  free(d);
+}
+
 int ccl_get_pk_spline_nk(ccl_cosmology *cosmo) {
   double ndecades = log10(cosmo->spline_params.K_MAX) - log10(cosmo->spline_params.K_MIN);
   return (int)ceil(ndecades*cosmo->spline_params.N_K);
@@ -597,3 +615,18 @@ void ccl_get_pk_spline_lk_array(ccl_cosmology *cosmo,int ndout,double* doutput,i
   }
   free(d);
 }
+
+void ccl_get_pk_spline_lk_array_from_params(ccl_spline_params *spline_params,
+                                            int ndout, double *doutput, int *status) {
+  double *d = NULL;
+  if (*status == 0) {
+    d = ccl_log_spacing(spline_params->K_MIN, spline_params->K_MAX, ndout);
+    if (d == NULL)
+      *status = CCL_ERROR_MEMORY;
+  }
+  if (*status == 0) {
+    for(int ii=0; ii < ndout; ii++)
+      doutput[ii] = log(d[ii]);
+  }
+  free(d);
+}
